@@ -81,48 +81,5 @@ C      Lhalf = (1.d0-x)*besseli(mxh,0.d0,2.d0)-x*besseli(mxh,1.d0,2.d0)
       END IF
       RETURN
       END
-      subroutine rcstep(x,n)
-      implicit logical (a-z)
-      integer n
-      real*8 x(n)
-      integer i,counter
-      real*8 xt,xta,yt,erice
-      external erice
-C ####################################################
-C  Attempt to parallelize causes errors
-C  " ****snapping into wrong generation "
-C  probably coming from http://svn.r-project.org/R/trunk/src/main/memory.c
-C ####################################################
-C$OMP PARALLEL DEFAULT(NONE)
-C$OMP& SHARED(x,n)
-C$OMP& PRIVATE(i,counter,xt,xta,yt)
-C$OMP DO SCHEDULE(GUIDED)
-      DO i=1,n
-         counter=0
-         xta = 0
-         xt  = x(i)
-         yt  = xt
-         DO while (abs(xt-xta).gt.4d-4.and.(counter.lt.50))
-            counter = counter + 1
-            xta = xt
-            if(xt.le.5d1) THEN
-               xt = max(0.d0,xt+yt-erice(xt))
-            ELSE
-               xt = yt
-            END IF
-C            if(counter.eq.100) THEN
-C               call intpr("maxit in i",10,i,1)
-C               call dblepr("yt",2,yt,1)
-C               call dblepr("xt",2,xt,1)
-C               call dblepr("xta",3,xta,1)
-C            END IF
-         END DO
-         x(i) = xt
-      END DO
-C$OMP END DO NOWAIT
-C$OMP END PARALLEL
-C$OMP FLUSH(x)
-      RETURN
-      END
       
       
